@@ -29,15 +29,11 @@
 
 RunnerModel::RunnerModel(QObject *parent) : QAbstractListModel(parent)
 , m_favoritesModel(0)
+, m_appletInterface(nullptr)
 , m_runnerManager(0)
 , m_mergeResults(false)
 , m_deleteWhenEmpty(false)
 {
-    QHash<int, QByteArray> roles;
-    roles.insert(Qt::DisplayRole, "display");
-
-    setRoleNames(roles);
-
     m_queryTimer.setSingleShot(true);
     m_queryTimer.setInterval(10);
     connect(&m_queryTimer, SIGNAL(timeout()), this, SLOT(startQuery()));
@@ -47,6 +43,11 @@ RunnerModel::~RunnerModel()
 {
 }
 
+QHash<int, QByteArray> RunnerModel::roleNames() const
+{
+    return {{ Qt::DisplayRole, "display" }};
+}
+
 AbstractModel *RunnerModel::favoritesModel() const
 {
     return m_favoritesModel;
@@ -67,6 +68,26 @@ void RunnerModel::setFavoritesModel(AbstractModel *model)
     }
 }
 
+QObject *RunnerModel::appletInterface() const
+{
+    return m_appletInterface;
+}
+
+void RunnerModel::setAppletInterface(QObject *appletInterface)
+{
+    if (m_appletInterface != appletInterface) {
+        m_appletInterface = appletInterface;
+
+        clear();
+
+        if (!m_query.isEmpty()) {
+            m_queryTimer.start();
+        }
+
+        emit appletInterfaceChanged();
+    }
+}
+
 bool RunnerModel::deleteWhenEmpty() const
 {
     return m_deleteWhenEmpty;
