@@ -19,32 +19,26 @@
 */
 
 #include "konq_popupmenu.h"
+
+#include <KActionCollection>
+
 #include <kfileitemlistproperties.h>
-#include "konq_popupmenuplugin.h"
 #include "konq_copytomenu.h"
 #include "kfileitemactions.h"
-#include "kfileitemactionplugin.h"
 #include "kabstractfileitemactionplugin.h"
 #include "kpropertiesdialog.h"
 
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kbookmarkmanager.h>
 #include <kbookmarkdialog.h>
-#include <kdebug.h>
 #include <krun.h>
 #include <kprotocolmanager.h>
-#include <QIcon>
 #include <knewfilemenu.h>
-#include <kiconloader.h>
-#include <kinputdialog.h>
-#include <kglobalsettings.h>
 #include <kmimetypetrader.h>
-#include <kstandarddirs.h>
 #include <kconfiggroup.h>
+#include <KSharedConfig>
 #include <kdesktopfile.h>
-#include <kfileshare.h>
 #include <kauthorized.h>
-#include <kglobal.h>
 #include <kacceleratormanager.h>
 #include <KIO/EmptyTrashJob>
 #include <KIO/JobUiDelegate>
@@ -53,6 +47,7 @@
 #include <KJobUiDelegate>
 #include <KMimeTypeEditor>
 
+#include <QIcon>
 #include <QFileInfo>
 
 /*
@@ -80,15 +75,14 @@
 class KonqPopupMenuPrivate
 {
 public:
-    KonqPopupMenuPrivate(KonqPopupMenu* qq, KActionCollection & actions, QWidget* parentWidget)
+    KonqPopupMenuPrivate(KonqPopupMenu *qq, KActionCollection &actions, QWidget *parentWidget)
         : q(qq),
           m_parentWidget(parentWidget),
-          m_itemFlags(KParts::BrowserExtension::DefaultPopupItems),
-	  m_pMenuNew(0),
+          m_popupFlags(KonqPopupMenu::DefaultPopupItems),
+          m_pMenuNew(0),
           m_copyToMenu(parentWidget),
-	  m_bookmarkManager(0),
-          m_actions(actions),
-          m_ownActionCollection(static_cast<QWidget *>(0))
+          m_bookmarkManager(0),
+          m_actions(actions)
     {
     }
 
@@ -97,10 +91,11 @@ public:
         qDeleteAll(m_ownActions);
     }
 
-    void addNamedAction(const QString& name);
-    void addGroup(const QString& name);
+    void addNamedAction(const char *name);
+    void addGroup(KonqPopupMenu::ActionGroup group);
     void addPlugins();
-    void init(KonqPopupMenu::Flags kpf, KParts::BrowserExtension::PopupFlags itemFlags);
+    void populate();
+    void aboutToShow();
 
     void slotPopupNewDir();
     void slotPopupNewView();
@@ -110,62 +105,57 @@ public:
     void slotPopupAddToBookmark();
     void slotPopupMimeType();
     void slotPopupProperties();
-    void slotOpenShareFileDialog();
     void slotShowOriginalFile();
 
-    KonqPopupMenu* q;
-    QWidget* m_parentWidget;
+    KonqPopupMenu *q;
+    QWidget *m_parentWidget;
     QString m_urlTitle;
-    KParts::BrowserExtension::PopupFlags m_itemFlags;
+    KonqPopupMenu::Flags m_popupFlags;
     KNewFileMenu *m_pMenuNew;
     QUrl m_sViewURL;
     KFileItemListProperties m_popupItemProperties;
     KFileItemActions m_menuActions;
     KonqCopyToMenu m_copyToMenu;
-    KBookmarkManager* m_bookmarkManager;
+    KBookmarkManager *m_bookmarkManager;
     KActionCollection &m_actions;
-    KActionCollection m_ownActionCollection; // only used by plugins; KDE5: pass m_ownActions instead
     QList<QAction *> m_ownActions;
-    KParts::BrowserExtension::ActionGroupMap m_actionGroups;
+    KonqPopupMenu::ActionGroupMap m_actionGroups;
 };
 
 //////////////////
 
 KonqPopupMenu::KonqPopupMenu(const KFileItemList &items,
                              const QUrl &viewURL,
-                             KActionCollection & actions,
-                             KNewFileMenu * newMenu,
-                             Flags kpf,
-                             KParts::BrowserExtension::PopupFlags flags,
-                             QWidget * parentWidget,
-                             KBookmarkManager *mgr,
-                             const KParts::BrowserExtension::ActionGroupMap& actionGroups)
-  : QMenu(parentWidget),
-    d(new KonqPopupMenuPrivate(this, actions, parentWidget))
+                             KActionCollection &actions,
+                             Flags popupFlags,
+                             QWidget *parentWidget)
+    : QMenu(parentWidget),
+      d(new KonqPopupMenuPrivate(this, actions, parentWidget))
 {
-    d->m_actionGroups = actionGroups;
-    d->m_pMenuNew = newMenu;
     d->m_sViewURL = viewURL;
-    d->m_bookmarkManager = mgr;
     d->m_popupItemProperties.setItems(items);
     d->m_menuActions.setParentWidget(parentWidget);
-    d->init(kpf, flags);
+    d->m_popupFlags = popupFlags;
 
-    KAcceleratorManager::manage(this);
+    connect(this, &QMenu::aboutToShow, this, [this]() { d->aboutToShow(); });
 }
 
-void KonqPopupMenuPrivate::addNamedAction(const QString& name)
+void KonqPopupMenuPrivate::addNamedAction(const char *name)
 {
-    QAction* act = m_actions.action(name);
-    if (act)
+    QAction *act = m_actions.action(QString::fromLatin1(name));
+    if (act) {
         q->addAction(act);
+    }
 }
 
-void KonqPopupMenuPrivate::init(KonqPopupMenu::Flags kpf, KParts::BrowserExtension::PopupFlags flags)
+void KonqPopupMenuPrivate::aboutToShow()
 {
-    m_itemFlags = flags;
-    q->setFont(KGlobalSettings::menuFont());
+    populate();
+    KAcceleratorManager::manage(q);
+}
 
+void KonqPopupMenuPrivate::populate()
+{
     Q_ASSERT(m_popupItemProperties.items().count() >= 1);
 
     bool bTrashIncluded = false;
@@ -173,21 +163,19 @@ void KonqPopupMenuPrivate::init(KonqPopupMenu::Flags kpf, KParts::BrowserExtensi
     const KFileItemList lstItems = m_popupItemProperties.items();
     KFileItemList::const_iterator it = lstItems.constBegin();
     const KFileItemList::const_iterator kend = lstItems.constEnd();
-    for ( ; it != kend; ++it )
-    {
+    for (; it != kend; ++it) {
         const QUrl url = (*it).url();
-        if ( !bTrashIncluded && (( url.scheme() == QLatin1String("trash") && url.path().length() <= 1 ) ) ) {
+        if (!bTrashIncluded && ((url.scheme() == QLatin1String("trash") && url.path().length() <= 1))) {
             bTrashIncluded = true;
         }
     }
 
     const bool isDirectory = m_popupItemProperties.isDirectory();
     const bool sReading = m_popupItemProperties.supportsReading();
-    bool sDeleting = (m_itemFlags & KParts::BrowserExtension::NoDeletion) == 0
+    bool sDeleting = (m_popupFlags & KonqPopupMenu::NoDeletion) == 0
                      && m_popupItemProperties.supportsDeleting();
     const bool sWriting = m_popupItemProperties.supportsWriting();
     const bool sMoving = sDeleting && m_popupItemProperties.supportsMoving();
-    const bool isLocal = m_popupItemProperties.isLocal();
 
     QUrl url = m_sViewURL.adjusted(QUrl::NormalizePathSegments);
 
@@ -198,21 +186,21 @@ void KonqPopupMenuPrivate::init(KonqPopupMenu::Flags kpf, KParts::BrowserExtensi
     bool isSymLinkInSameDir = false; // true for "ln -s foo bar", false for links to foo/sub or /foo
 
     //check if url is current directory
-    if ( lstItems.count() == 1 )
-    {
-        KFileItem firstPopupItem( lstItems.first() );
+    if (lstItems.count() == 1) {
+        KFileItem firstPopupItem(lstItems.first());
         if (firstPopupItem.isLink()) {
             isSymLink = true;
-            isSymLinkInSameDir = !firstPopupItem.linkDest().contains('/');
+            isSymLinkInSameDir = !firstPopupItem.linkDest().contains(QLatin1Char('/'));
         }
-        QUrl firstPopupURL( firstPopupItem.url().adjusted(QUrl::NormalizePathSegments) );
+        QUrl firstPopupURL(firstPopupItem.url().adjusted(QUrl::NormalizePathSegments));
         //kDebug(1203) << "View path is " << url.url();
         //kDebug(1203) << "First popup path is " << firstPopupURL.url();
         currentDir = (firstPopupURL.matches(url, QUrl::StripTrailingSlash));
-        if ( firstPopupItem.isDesktopFile() ) {
-            KDesktopFile desktopFile( firstPopupItem.localPath() );
+        if (firstPopupItem.isDesktopFile()) {
+            KDesktopFile desktopFile(firstPopupItem.localPath());
             const KConfigGroup cfg = desktopFile.desktopGroup();
-            isTrashLink = ( cfg.readEntry("Type") == QLatin1String("Link") && cfg.readEntry("URL") == QLatin1String("trash:/") );
+            isTrashLink = cfg.readEntry("Type") == QLatin1String("Link")
+                          && cfg.readEntry("URL") == QLatin1String("trash:/");
         }
 
         if (isTrashLink) {
@@ -226,70 +214,64 @@ void KonqPopupMenuPrivate::init(KonqPopupMenu::Flags kpf, KParts::BrowserExtensi
 
     const bool isIntoTrash = (url.scheme() == QLatin1String("trash")) && !isCurrentTrash; // trashed file, not trash:/ itself
 
-    const bool bIsLink  = (m_itemFlags & KParts::BrowserExtension::IsLink);
+    const bool bIsLink  = (m_popupFlags & KonqPopupMenu::IsLink);
 
     //kDebug() << "isLocal=" << isLocal << " url=" << url << " isCurrentTrash=" << isCurrentTrash << " isIntoTrash=" << isIntoTrash << " bTrashIncluded=" << bTrashIncluded;
 
     //////////////////////////////////////////////////////////////////////////
 
-    addGroup( QStringLiteral("topactions") ); // used e.g. for ShowMenuBar. includes a separator at the end
+    addGroup(KonqPopupMenu::TopActions); // used e.g. for ShowMenuBar. includes a separator at the end
 
-    QAction * act;
+    QAction *act;
 
     QAction *actNewWindow = 0;
 
 #if 0 // TODO in the desktop code itself.
-    if (( flags & KParts::BrowserExtension::ShowProperties ) && isOnDesktop &&
-        !KAuthorized::authorizeKAction("editable_desktop_icons"))
-    {
-        flags &= ~KParts::BrowserExtension::ShowProperties; // remove flag
+    if ((flags & KonqPopupMenu::ShowProperties) && isOnDesktop &&
+            !KAuthorized::authorizeKAction("editable_desktop_icons")) {
+        flags &= ~KonqPopupMenu::ShowProperties; // remove flag
     }
 #endif
 
     // Either 'newview' is in the actions we're given (probably in the tabhandling group)
     // or we need to insert it ourselves (e.g. for the desktop).
     // In the first case, actNewWindow must remain 0.
-    if ( ((kpf & KonqPopupMenu::ShowNewWindow) != 0) && sReading )
-    {
+    if (((m_popupFlags & KonqPopupMenu::ShowNewWindow) != 0) && sReading) {
         const QString openStr = i18n("&Open");
         actNewWindow = new QAction(m_parentWidget /*for status tips*/);
         m_ownActions.append(actNewWindow);
-        actNewWindow->setIcon( QIcon::fromTheme(QStringLiteral("window-new")) );
-        actNewWindow->setText( openStr );
+        actNewWindow->setIcon(QIcon::fromTheme(QStringLiteral("window-new")));
+        actNewWindow->setText(openStr);
         QObject::connect(actNewWindow, &QAction::triggered, [this]() {
             slotPopupNewView();
         });
     }
 
-    if ( isDirectory && sWriting && !isCurrentTrash ) // A dir, and we can create things into it
-    {
-        const bool mkdirRequested = m_itemFlags & KParts::BrowserExtension::ShowCreateDirectory;
-        if ( (currentDir || mkdirRequested) && m_pMenuNew ) // Current dir -> add the "new" menu
-        {
+    if (isDirectory && sWriting && !isCurrentTrash) { // A dir, and we can create things into it
+        const bool mkdirRequested = m_popupFlags & KonqPopupMenu::ShowCreateDirectory;
+        if ((currentDir || mkdirRequested) && m_pMenuNew) { // Current dir -> add the "new" menu
             // As requested by KNewFileMenu :
             m_pMenuNew->checkUpToDate();
             m_pMenuNew->setPopupFiles(m_popupItemProperties.urlList());
 
-            q->addAction( m_pMenuNew );
+            q->addAction(m_pMenuNew);
             q->addSeparator();
-        }
-        else if (mkdirRequested)
-        {
+        } else if (mkdirRequested) {
             QAction *actNewDir = new QAction(m_parentWidget);
             m_ownActions.append(actNewDir);
-            actNewDir->setIcon( QIcon::fromTheme(QStringLiteral("folder-new")) );
-            actNewDir->setText( i18n( "Create &Folder..." ) );
+            actNewDir->setIcon(QIcon::fromTheme(QStringLiteral("folder-new")));
+            actNewDir->setText(i18n("Create &Folder..."));
             QObject::connect(actNewDir, &QAction::triggered, [this]() {
                 slotPopupNewDir();
             });
-            q->addAction( actNewDir );
+            q->addAction(actNewDir);
             q->addSeparator();
         }
-    } else if ( isIntoTrash ) {
+    } else if (isIntoTrash) {
         // Trashed item, offer restoring
         act = new QAction(m_parentWidget /*for status tips*/);
         m_ownActions.append(act);
-        act->setText( i18n( "&Restore" ) );
+        act->setText(i18n("&Restore"));
         //PORT QT5 act->setHelpText(i18n("Restores this file or directory, back to the location where it was deleted from initially"));
         QObject::connect(act, &QAction::triggered, [this]() {
             slotPopupRestoreTrashedItems();
@@ -297,14 +279,15 @@ void KonqPopupMenuPrivate::init(KonqPopupMenu::Flags kpf, KParts::BrowserExtensi
         q->addAction(act);
     }
 
-    if (m_itemFlags & KParts::BrowserExtension::ShowNavigationItems)
-    {
-        if (m_itemFlags & KParts::BrowserExtension::ShowUp)
-            addNamedAction( QStringLiteral("go_up") );
-        addNamedAction( QStringLiteral("go_back") );
-        addNamedAction( QStringLiteral("go_forward") );
-        if (m_itemFlags & KParts::BrowserExtension::ShowReload)
-            addNamedAction( QStringLiteral("reload") );
+    if (m_popupFlags & KonqPopupMenu::ShowNavigationItems) {
+        if (m_popupFlags & KonqPopupMenu::ShowUp) {
+            addNamedAction("go_up");
+        }
+        addNamedAction("go_back");
+        addNamedAction("go_forward");
+        if (m_popupFlags & KonqPopupMenu::ShowReload) {
+            addNamedAction("reload");
+        }
         q->addSeparator();
     }
 
@@ -325,108 +308,109 @@ void KonqPopupMenuPrivate::init(KonqPopupMenu::Flags kpf, KParts::BrowserExtensi
         q->addAction(actNewWindow);
         q->addSeparator();
     }
-    addGroup( QStringLiteral("tabhandling") ); // includes a separator at the end
+    addGroup(KonqPopupMenu::TabHandlingActions);   // includes a separator at the end
 
-    if (m_itemFlags & KParts::BrowserExtension::ShowUrlOperations) {
-        if ( !currentDir && sReading ) {
-            if ( sDeleting ) {
-                addNamedAction( QStringLiteral("cut") );
+    if (m_popupFlags & KonqPopupMenu::ShowUrlOperations) {
+        if (!currentDir && sReading) {
+            if (sDeleting) {
+                addNamedAction("cut");
             }
-            addNamedAction( QStringLiteral("copy") );
+            addNamedAction("copy");
         }
 
-        if ( isDirectory && sWriting ) {
-            if ( currentDir )
-                addNamedAction( QStringLiteral("paste") );
-            else
-                addNamedAction( QStringLiteral("pasteto") );
+        if (isDirectory && sWriting) {
+            if (currentDir) {
+                addNamedAction("paste");
+            } else {
+                addNamedAction("pasteto");
+            }
         }
     }
-    if ( isCurrentTrash )
-    {
+    if (isCurrentTrash) {
         act = new QAction(m_parentWidget);
         m_ownActions.append(act);
-        act->setIcon( QIcon::fromTheme(QStringLiteral("trash-empty")) );
-        act->setText( i18n( "&Empty Trash Bin" ) );
-        KConfig trashConfig( QStringLiteral("trashrc"), KConfig::SimpleConfig);
-        act->setEnabled( !trashConfig.group("Status").readEntry( "Empty", true ) );
+        act->setIcon(QIcon::fromTheme(QStringLiteral("trash-empty")));
+        act->setText(i18n("&Empty Trash Bin"));
+        KConfig trashConfig(QStringLiteral("trashrc"), KConfig::SimpleConfig);
+        act->setEnabled(!trashConfig.group("Status").readEntry("Empty", true));
         QObject::connect(act, &QAction::triggered, [this]() {
             slotPopupEmptyTrashBin();
         });
         q->addAction(act);
     }
-    if ( isCurrentTrash )
-    {
-	act = new QAction(m_parentWidget);
-	m_ownActions.append(act);
-	act->setIcon( QIcon::fromTheme(QStringLiteral("trash-empty")) );
-	act->setText( i18n( "&Configure Trash Bin" ) );
-	QObject::connect(act, &QAction::triggered, [this]() {
-        slotConfigTrashBin();
-    });
-	q->addAction(act);
+    if (isCurrentTrash) {
+        act = new QAction(m_parentWidget);
+        m_ownActions.append(act);
+        act->setIcon(QIcon::fromTheme(QStringLiteral("trash-empty")));
+        act->setText(i18n("&Configure Trash Bin"));
+        QObject::connect(act, &QAction::triggered, [this]() {
+            slotConfigTrashBin();
+        });
+        q->addAction(act);
     }
 
     // This is used by KHTML, see khtml_popupmenu.rc (copy, selectAll, searchProvider etc.)
     // and by DolphinPart (rename, trash, delete)
-    addGroup( QStringLiteral("editactions") );
+    addGroup(KonqPopupMenu::EditActions);
 
-    if (m_itemFlags & KParts::BrowserExtension::ShowTextSelectionItems) {
+    if (m_popupFlags & KonqPopupMenu::ShowTextSelectionItems) {
         // OK, we have to stop here.
 
         // Anything else that is provided by the part
-        addGroup( QStringLiteral("partactions") );
+        addGroup(KonqPopupMenu::CustomActions);
         return;
     }
 
-    if ( !isCurrentTrash && !isIntoTrash && (m_itemFlags & KParts::BrowserExtension::ShowBookmark))
-    {
+    if (!isCurrentTrash && !isIntoTrash && (m_popupFlags & KonqPopupMenu::ShowBookmark)) {
         QString caption;
-        if (currentDir)
-        {
-           const bool httpPage = m_sViewURL.scheme().startsWith(QLatin1String("http"), Qt::CaseInsensitive);
-           if (httpPage)
-              caption = i18n("&Bookmark This Page");
-           else
-              caption = i18n("&Bookmark This Location");
+        if (currentDir) {
+            const bool httpPage = m_sViewURL.scheme().startsWith(QLatin1String("http"), Qt::CaseInsensitive);
+            if (httpPage) {
+                caption = i18n("&Bookmark This Page");
+            } else {
+                caption = i18n("&Bookmark This Location");
+            }
+        } else if (isDirectory) {
+            caption = i18n("&Bookmark This Folder");
+        } else if (bIsLink) {
+            caption = i18n("&Bookmark This Link");
+        } else {
+            caption = i18n("&Bookmark This File");
         }
-        else if (isDirectory)
-           caption = i18n("&Bookmark This Folder");
-        else if (bIsLink)
-           caption = i18n("&Bookmark This Link");
-        else
-           caption = i18n("&Bookmark This File");
 
         act = new QAction(m_parentWidget);
         m_ownActions.append(act);
-        act->setObjectName( QStringLiteral("bookmark_add" )); // for unittest
-        act->setIcon( QIcon::fromTheme(QStringLiteral("bookmark-new")) );
-        act->setText( caption );
+        act->setObjectName(QLatin1String("bookmark_add"));   // for unittest
+        act->setIcon(QIcon::fromTheme(QStringLiteral("bookmark-new")));
+        act->setText(caption);
         QObject::connect(act, &QAction::triggered, [this]() {
             slotPopupAddToBookmark();
         });
-        if (lstItems.count() > 1)
+        if (lstItems.count() > 1) {
             act->setEnabled(false);
-        if (KAuthorized::authorizeKAction(QStringLiteral("bookmarks")))
-            q->addAction( act );
-        if (bIsLink)
-            addGroup( QStringLiteral("linkactions") ); // see khtml
+        }
+        if (KAuthorized::authorizeKAction(QStringLiteral("bookmarks"))) {
+            q->addAction(act);
+        }
+        if (bIsLink) {
+            addGroup(KonqPopupMenu::LinkActions);    // see khtml
+        }
     }
 
     // "Open With" actions
 
     m_menuActions.setItemListProperties(m_popupItemProperties);
 
-    if ( sReading ) {
+    if (sReading) {
         m_menuActions.addOpenWithActionsTo(q, QStringLiteral("DesktopEntryName != 'kfmclient' and DesktopEntryName != 'kfmclient_dir' and DesktopEntryName != 'kfmclient_html'"));
 
-        QList<QAction *> previewActions = m_actionGroups.value(QStringLiteral("preview"));
+        QList<QAction *> previewActions = m_actionGroups.value(KonqPopupMenu::PreviewActions);
         if (!previewActions.isEmpty()) {
             if (previewActions.count() == 1) {
                 q->addAction(previewActions.first());
             } else {
-                QMenu* subMenu = new QMenu(i18n("Preview In"), q);
-                subMenu->menuAction()->setObjectName( QStringLiteral("preview_submenu" )); // for the unittest
+                QMenu *subMenu = new QMenu(i18n("Preview In"), q);
+                subMenu->menuAction()->setObjectName(QLatin1String("preview_submenu"));   // for the unittest
                 q->addMenu(subMenu);
                 subMenu->addActions(previewActions);
             }
@@ -442,8 +426,8 @@ void KonqPopupMenuPrivate::init(KonqPopupMenu::Flags kpf, KParts::BrowserExtensi
     KSharedConfig::Ptr dolphin = KSharedConfig::openConfig(QStringLiteral("dolphinrc"));
 
     // CopyTo/MoveTo menus
-    if (m_itemFlags & KParts::BrowserExtension::ShowUrlOperations &&
-        KConfigGroup(dolphin, "General").readEntry("ShowCopyMoveMenu", false)) {
+    if (m_popupFlags & KonqPopupMenu::ShowUrlOperations &&
+            KConfigGroup(dolphin, "General").readEntry("ShowCopyMoveMenu", false)) {
 
         m_copyToMenu.setItems(lstItems);
         m_copyToMenu.setReadOnly(sMoving == false);
@@ -452,75 +436,68 @@ void KonqPopupMenuPrivate::init(KonqPopupMenu::Flags kpf, KParts::BrowserExtensi
     }
 
     if (!isCurrentTrash && !isIntoTrash && sReading &&
-        (kpf & KonqPopupMenu::NoPlugins) == 0) {
+            (m_popupFlags & KonqPopupMenu::NoPlugins) == 0) {
         addPlugins(); // now it's time to add plugins
     }
 
-    if ( (m_itemFlags & KParts::BrowserExtension::ShowProperties) && KPropertiesDialog::canDisplay( lstItems ) ) {
+    if ((m_popupFlags & KonqPopupMenu::ShowProperties) && KPropertiesDialog::canDisplay(lstItems)) {
         act = new QAction(m_parentWidget);
         m_ownActions.append(act);
-        act->setObjectName( QStringLiteral("properties" )); // for unittest
-        act->setText( i18n( "&Properties" ) );
+        act->setObjectName(QLatin1String("properties"));   // for unittest
+        act->setText(i18n("&Properties"));
         QObject::connect(act, &QAction::triggered, [this]() {
             slotPopupProperties();
         });
         q->addAction(act);
     }
 
-    while ( !q->actions().isEmpty() &&
-            q->actions().last()->isSeparator() )
+    while (!q->actions().isEmpty() &&
+            q->actions().last()->isSeparator()) {
         delete q->actions().last();
-
-    if ( isDirectory && isLocal ) {
-        if ( KFileShare::authorization() == KFileShare::Authorized ) {
-            q->addSeparator();
-            act = new QAction(m_parentWidget);
-            m_ownActions.append(act);
-            act->setText( i18n("Share") );
-            QObject::connect(act, &QAction::triggered, [this]() {
-                slotOpenShareFileDialog();
-            });
-            q->addAction(act);
-        }
     }
 
     // Anything else that is provided by the part
-    addGroup( QStringLiteral("partactions") );
-}
+    addGroup(KonqPopupMenu::CustomActions);
 
-void KonqPopupMenuPrivate::slotOpenShareFileDialog()
-{
-    KPropertiesDialog* dlg = new KPropertiesDialog( m_popupItemProperties.items(), m_parentWidget );
-    dlg->showFileSharingPage();
-    dlg->exec();
+    QObject::connect(&m_menuActions, &KFileItemActions::openWithDialogAboutToBeShown, q, &KonqPopupMenu::openWithDialogAboutToBeShown);
 }
 
 KonqPopupMenu::~KonqPopupMenu()
 {
-  delete d;
-  //kDebug(1203) << "~KonqPopupMenu leave";
+    delete d;
+    //kDebug(1203) << "~KonqPopupMenu leave";
 }
 
-void KonqPopupMenu::setURLTitle( const QString& urlTitle )
+void KonqPopupMenu::setNewFileMenu(KNewFileMenu *newMenu)
+{
+    d->m_pMenuNew = newMenu;
+}
+
+void KonqPopupMenu::setBookmarkManager(KBookmarkManager *manager)
+{
+    d->m_bookmarkManager = manager;
+}
+
+void KonqPopupMenu::setActionGroups(const KonqPopupMenu::ActionGroupMap &actionGroups)
+{
+    d->m_actionGroups = actionGroups;
+}
+
+void KonqPopupMenu::setURLTitle(const QString &urlTitle)
 {
     d->m_urlTitle = urlTitle;
 }
 
-KFileItemActions* KonqPopupMenu::fileItemActions() const
-{
-    return &(d->m_menuActions);
-}
-
 void KonqPopupMenuPrivate::slotPopupNewView()
 {
-    Q_FOREACH(const QUrl& url, m_popupItemProperties.urlList()) {
+    Q_FOREACH (const QUrl &url, m_popupItemProperties.urlList()) {
         (void) new KRun(url, m_parentWidget);
     }
 }
 
 void KonqPopupMenuPrivate::slotPopupNewDir()
 {
-  m_pMenuNew->createDirectory();
+    m_pMenuNew->createDirectory();
 }
 
 void KonqPopupMenuPrivate::slotPopupEmptyTrashBin()
@@ -528,7 +505,7 @@ void KonqPopupMenuPrivate::slotPopupEmptyTrashBin()
     KIO::JobUiDelegate uiDelegate;
     uiDelegate.setWindow(m_parentWidget);
     if (uiDelegate.askDeleteConfirmation(QList<QUrl>(), KIO::JobUiDelegate::EmptyTrash, KIO::JobUiDelegate::DefaultConfirmation)) {
-        KIO::Job* job = KIO::emptyTrash();
+        KIO::Job *job = KIO::emptyTrash();
         KJobWidgets::setWindow(job, m_parentWidget);
         job->ui()->setAutoErrorHandlingEnabled(true); // or connect to the result signal
     }
@@ -536,7 +513,7 @@ void KonqPopupMenuPrivate::slotPopupEmptyTrashBin()
 
 void KonqPopupMenuPrivate::slotConfigTrashBin()
 {
-  KRun::run(QStringLiteral("kcmshell5 kcmtrash"), QList<QUrl>(), m_parentWidget);
+    KRun::run(QStringLiteral("kcmshell5 kcmtrash"), QList<QUrl>(), m_parentWidget);
 }
 
 void KonqPopupMenuPrivate::slotPopupRestoreTrashedItems()
@@ -554,11 +531,9 @@ void KonqPopupMenuPrivate::slotPopupAddToBookmark()
         const QString title = m_urlTitle.isEmpty() ? url.toDisplayString() : m_urlTitle;
         KBookmarkDialog dlg(m_bookmarkManager, m_parentWidget);
         dlg.addBookmark(title, url, QString());
-    }
-    else
-    {
+    } else {
         root = m_bookmarkManager->root();
-        Q_FOREACH(const QUrl& url, m_popupItemProperties.urlList()) {
+        Q_FOREACH (const QUrl &url, m_popupItemProperties.urlList()) {
             root.addBookmark(url.toDisplayString(), url, QString());
         }
         m_bookmarkManager->emitChanged(root);
@@ -575,31 +550,16 @@ void KonqPopupMenuPrivate::slotPopupProperties()
     KPropertiesDialog::showDialog(m_popupItemProperties.items(), m_parentWidget, false);
 }
 
-void KonqPopupMenuPrivate::addGroup(const QString& name)
+void KonqPopupMenuPrivate::addGroup(KonqPopupMenu::ActionGroup group)
 {
-    QList<QAction *> actions = m_actionGroups.value(name);
-    q->addActions(actions);
+    q->addActions(m_actionGroups.value(group));
 }
 
 void KonqPopupMenuPrivate::addPlugins()
 {
     QString commonMimeType = m_popupItemProperties.mimeType();
     if (commonMimeType.isEmpty()) {
-        commonMimeType = QStringLiteral("application/octet-stream");
-    }
-    const KService::List konqPlugins = KMimeTypeTrader::self()->query(commonMimeType, QStringLiteral("KonqPopupMenu/Plugin"), QStringLiteral("exist Library"));
-
-    if (!konqPlugins.isEmpty()) {
-        KService::List::ConstIterator iterator = konqPlugins.begin();
-        const KService::List::ConstIterator end = konqPlugins.end();
-        for(; iterator != end; ++iterator) {
-            //kDebug() << (*iterator)->name() << (*iterator)->library();
-            KonqPopupMenuPlugin *plugin = (*iterator)->createInstance<KonqPopupMenuPlugin>(q);
-            if (!plugin)
-                continue;
-            plugin->setParent(q);
-            plugin->setup(&m_ownActionCollection, m_popupItemProperties, q);
-        }
+        commonMimeType = QLatin1String("application/octet-stream");
     }
 
     const KService::List fileItemPlugins = KMimeTypeTrader::self()->query(commonMimeType, QStringLiteral("KFileItemAction/Plugin"), QStringLiteral("exist Library"));
@@ -607,20 +567,13 @@ void KonqPopupMenuPrivate::addPlugins()
         const KConfig config(QStringLiteral("kservicemenurc"), KConfig::NoGlobals);
         const KConfigGroup showGroup = config.group("Show");
 
-        foreach (const auto& service, fileItemPlugins) {
+        foreach (const auto &service, fileItemPlugins) {
             if (!showGroup.readEntry(service->desktopEntryName(), true)) {
                 // The plugin has been disabled
                 continue;
             }
 
-            // Old API (kdelibs-4.6.0 only)
-            KFileItemActionPlugin* plugin = service->createInstance<KFileItemActionPlugin>();
-            if (plugin) {
-                plugin->setParent(q);
-                q->addActions(plugin->actions(m_popupItemProperties, m_parentWidget));
-            }
-            // New API (kdelibs >= 4.6.1)
-            KAbstractFileItemActionPlugin* abstractPlugin = service->createInstance<KAbstractFileItemActionPlugin>();
+            KAbstractFileItemActionPlugin *abstractPlugin = service->createInstance<KAbstractFileItemActionPlugin>();
             if (abstractPlugin) {
                 abstractPlugin->setParent(q);
                 q->addActions(abstractPlugin->actions(m_popupItemProperties, m_parentWidget));
