@@ -21,12 +21,7 @@
 #define BINDINGS_H_
 
 #include <kactioncollection.h>
-#include <QLoggingCategory>
 
-Q_DECLARE_LOGGING_CATEGORY(KCM_KEYBOARD)
-
-
-//class QObject;
 class Rules;
 class LayoutUnit;
 template <typename T> class QList;
